@@ -77,14 +77,14 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
         """
             This function executes a show command to read specified parameter and enables triggering of the use case
             by testing the parameter value periodically
-                * Execute show command using python "cli" package or SSH
+                * Execute show command using python "cli" 
                 * Substitute parameters in the show command if required
                 * Use the dictionary returned by the parser to compare the value of "leaf" to the "test_value"
                 * Perform comparison using the "operator.xx" value in "relate"
                 * Periodically perform the test "retries" times waiting "interval" seconds between tries
 
             :param device: Device information and credentials for running show command
-            :param access_type: EXAMPLE to use the Python cli package in the guestshell or 'ssh' for ssh device access
+            :param access_type: 'cli' to use the Python cli package in the guestshell
             :param genie_parser_name: genie parser to use to process show command
             :param show_template: show command to execute with optional parameters identified by {0}, {1}, {2}
             :param pcount: Number of parameters to substitute in the show_command 0 to 3
@@ -141,26 +141,8 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
               debug_msg(debug_flag, f" ddr_show_trigger: cli python response: {str(response)}")
 
             else:
-        #
-        # Use SSH to run the show command
-        #
-              try:
-                options = '-q -oStrictHostKeyChecking=no -oUserKnownHostsFile=/dev/null -oPubkeyAuthentication=no'
-                ssh_cmd = 'ssh %s@%s %s "%s"' % (device[2], device[0], options, command)
-                debug_msg(debug_flag, f"ddr_show_trigger: ssh_cmd: {str(ssh_cmd)}")
-
-                child = pexpect.spawn(ssh_cmd, timeout= 20, encoding='utf-8')
-                child.delaybeforesend = None
-                child.expect(['\r\nPassword: ', '\r\npassword: ', 'Password: ', 'password: '])
-                child.sendline(device[3])
-                child.expect(pexpect.EOF) #result contains the ping result
-                response = child.before
-                debug_msg(debug_flag, f"ddr_show_trigger: ssh response: {str(response)}")
-
-              except Exception as e:
-                error_msg(f"ddr_show_trigger Exception: {str(e)}")
-                child.close()
-                raise
+              error_msg(f"ddr_show_trigger Exception: only cli device access option currently supported")
+              raise
     #
     # parse the response to get the test leaf value
     #
